OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Kho lưu trữ tạm thời không khả dụng",
    "Storage invalid" : "Lưu trữ không hợp lệ",
    "Unknown error" : "Lỗi chưa biết",
    "All files" : "Tất cả tệp tin",
    "Recent" : "Gần đây",
    "Favorites" : "Ưa thích",
    "File could not be found" : "Tệp tin không tồn tại",
    "Move or copy" : "Di chuyển hoặc sao chép",
    "Download" : "Tải về",
    "Delete" : "Xóa",
    "Home" : "Nhà",
    "Close" : "Đóng",
    "Could not create folder \"{dir}\"" : "Không thể tạo thư mục “{dir}”",
    "Upload cancelled." : "Hủy tải lên",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "không thể tải {filename} lên do nó là một thư mục hoặc có kích thước bằng 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Không đủ dung lượng trống, bạn đang tải {size1} nhưng chỉ còn {size2} trống",
    "Target folder \"{dir}\" does not exist any more" : "Thư mục đích \"{dir}\" không còn tồn tại",
    "Not enough free space" : "Không đủ dung lượng trống",
    "Uploading …" : "Đang tải lên …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} trong tổng số {totalSize} ({bitrate})",
    "Actions" : "Actions",
    "Rename" : "Sửa tên",
    "Copy" : "Sao chép",
    "Delete folder" : "Xóa thư mục",
    "Disconnect storage" : "Bộ lưu trữ đã ngắt kết nối",
    "Unshare" : "Bỏ chia sẻ",
    "Could not load info for file \"{file}\"" : "Không thể tải thông tin cho tệp \"{file}\"",
    "Files" : "Tập tin",
    "Details" : "Chi tiết",
    "Select" : "Chọn",
    "Pending" : "Đang chờ",
    "Unable to determine date" : "Không thể xác định ngày",
    "This operation is forbidden" : "Thao tác bị cấm",
    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
    "Could not move \"{file}\", target exists" : "Không thể di chuyển \"{file}\", trùng đích đến",
    "Could not move \"{file}\"" : "Không thể di chuyển \"{file}\"",
    "Could not copy \"{file}\", target exists" : "Không thể sao chép \"{file}\",  tệp tin đích đã tồn tại",
    "Could not copy \"{file}\"" : "Không thể sao chép tệp tin \"{file}\"",
    "Copied {origin} inside {destination}" : "Được sao chép {origin} vào trong {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Đã sao chép {origin} và {nbfiles} các file vào trong {destination}",
    "{newName} already exists" : "{newName} đã có",
    "Could not rename \"{fileName}\", it does not exist any more" : "Không thể đổi tên \"{fileName}\", tập tin không tồn tại",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{targetName}\" đã được dùng trong thư mục \"{dir}\". Hãy thử tên khác",
    "Could not rename \"{fileName}\"" : "Không thể đổi tên \"{fileName}\"",
    "Could not create file \"{file}\"" : "Không thể tạo tập tin \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Không thể tạo tập tin \"{file}\" vì đã có ",
    "Could not create folder \"{dir}\" because it already exists" : "Không thể tạo thư mục “{dir}” vì đã có",
    "Error deleting file \"{fileName}\"." : "Lỗi khi xóa tập tin \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Không có kết quả tìm kiếm trong các thư mục khác cho {tag}{filter}{endtag}",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "_%n folder_::_%n folders_" : ["%n thư mục"],
    "_%n file_::_%n files_" : ["%n tập tin"],
    "{dirs} and {files}" : "{dirs} và {files}",
    "_including %n hidden_::_including %n hidden_" : ["Bao gồm %n ẩn"],
    "You don’t have permission to upload or create files here" : "Bạn không có quyền upload hoặc tạo files ở đây",
    "_Uploading %n file_::_Uploading %n files_" : ["Đang tải lên %n tập tin"],
    "New" : "Tạo mới",
    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
    "File name cannot be empty." : "Tên file không được rỗng",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" không phải là loại tập tin được cho phép",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Dung lượng của {owner} đã hết, không thể tải hay đồng bộ dữ liệu mới!",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Dung lượng của {owner} gần hết ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["khớp '{filter}'"],
    "View in folder" : "Xem trong thư mục",
    "Copied!" : "Đã sao chép!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Sao chép liên kết trực tiếp (chỉ hoạt động đối với người dùng có quyền truy nhập tới tệp tin/thư mục này)",
    "Path" : "Đường dẫn",
    "_%n byte_::_%n bytes_" : ["%n bytes"],
    "Favorited" : "Được ưa thích",
    "Favorite" : "Ưu thích",
    "New folder" : "Tạo thư mục",
    "Upload file" : "Tải lên tập tin",
    "Remove from favorites" : "Xóa khỏi ưa thích",
    "Add to favorites" : "Thêm vào ưa thích",
    "An error occurred while trying to update the tags" : "Đã xảy ra lỗi khi cố gắng cập nhật tags",
    "Added to favorites" : "Đã thêm vào mục yêu thích",
    "Removed from favorites" : "Đã xóa khỏi mục ưa thích",
    "You added {file} to your favorites" : "Bạn đã thêm {file} vào mục ưa thích của bạn",
    "You removed {file} from your favorites" : "Bạn đã xóa {file} khỏi mục ưa thích của mình",
    "File changes" : "Tệp thay đổi",
    "Created by {user}" : "Được tạo bởi {user}",
    "Changed by {user}" : "Thay đổi bởi {user}",
    "Deleted by {user}" : "Đã xóa bởi {user}",
    "Restored by {user}" : "Được khôi phục bởi {user}",
    "Renamed by {user}" : "Đã đổi tên bởi {user}",
    "Moved by {user}" : "Đã di chuyển bởi {user}",
    "\"remote user\"" : "\"người dùng từ xa\"",
    "You created {file}" : "Bạn đã tạo {file}",
    "{user} created {file}" : "{user} đã tạo {file}",
    "{file} was created in a public folder" : "{file} đã được tạo trong một thư mục công khai",
    "You changed {file}" : "Bạn đã thay đổi {file}",
    "{user} changed {file}" : "{user} đã thay đổi {file}",
    "You deleted {file}" : "Bạn đã xóa {file}",
    "{user} deleted {file}" : "{user} đã xóa {file}",
    "You restored {file}" : "Bạn đã khôi phục {file}",
    "{user} restored {file}" : "{user} đã khôi phục {file}",
    "You renamed {oldfile} to {newfile}" : "Bạn đã đổi tên {oldfile} thành {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} đổi tên thành {oldfile} thành {newfile}",
    "You moved {oldfile} to {newfile}" : "Bạn đã chuyển {oldfile} tới {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} đã chuyển {oldfile} tới {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Một tệp đã được thêm hoặc bị xóa khỏi <strong>mục yêu thích của bạn</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Tệp hoặc thư mục đã bị <strong>xóa</strong>",
    "A file or folder has been <strong>restored</strong>" : "Tệp hoặc thư mục đã được <strong>khôi phục</strong>",
    "Unlimited" : "Không giới hạn",
    "Upload (max. %s)" : "Tải lên (tối đa. %s)",
    "Change" : "Chỉnh sửa",
    "%1$s of %2$s used" : "%1$s trên %2$s đã sử dụng",
    "Settings" : "Cài đặt",
    "Show hidden files" : "Hiển thị cac file bị ẩn",
    "WebDAV" : "WebDAV",
    "No files in here" : "Không có tệp nào",
    "Upload some content or sync with your devices!" : "Tải lên một số nội dung hoặc đồng bộ với thiết bị của bạn!",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Select all" : "Chọn tất cả",
    "Upload too large" : "Tập tin tải lên quá lớn",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
    "Files and folders you mark as favorite will show up here" : "Các tệp và thư mục mà bạn đánh dấu là yêu thích sẽ hiển thị ở đây",
    "Tags" : "Nhãn",
    "Deleted files" : "Thùng rác",
    "Shares" : "Chia sẻ",
    "Shared with others" : "Chia sẻ với người khác",
    "Shared with you" : "Đã chia sẻ với bạn",
    "Shared by link" : "Được chia sẻ bởi liên kết",
    "Text file" : "Tập tin văn bản",
    "File handling" : "Xử lý tập tin",
    "Maximum upload size" : "Kích thước tối đa ",
    "max. possible: " : "tối đa cho phép:",
    "Save" : "Lưu",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Với PHP-FPM, có thể mất 5 phút để áp dụng các thay đổi.",
    "Missing permissions to edit from here." : "Thiếu quyền để chỉnh sửa từ đây.",
    "Cancel upload" : "Hủy tải lên"
},
"nplurals=1; plural=0;");
